@@ -16,7 +16,7 @@ def create_parser():
     """Create argument parser for ONVIF CLI"""
     parser = argparse.ArgumentParser(
         prog="onvif",
-        description=f"{colorize('ONVIF Terminal Client', 'yellow')} —\nhttps://github.com/nirsimetri/onvif-python",
+        description=f"{colorize('ONVIF Terminal Client', 'yellow')} — v0.1.4\nhttps://github.com/nirsimetri/onvif-python",
         formatter_class=argparse.RawDescriptionHelpFormatter,
         epilog=f"""
 Examples:
@@ -107,6 +107,11 @@ Examples:
         "params", nargs="*", help="Method parameters as Simple Parameter or JSON string"
     )
 
+    # ONVI CLI
+    parser.add_argument(
+        "--version", "-v", action="store_true", help="Show ONVIF CLI version and exit"
+    )
+
     return parser
 
 
@@ -124,6 +129,17 @@ def main():
 
     args = parser.parse_intermixed_args()
 
+    # Show ONVIF CLI version
+    if args.version:
+        print(colorize("0.1.4", "yellow"))
+        sys.exit(0)
+
+    # Validate arguments early (before discovery)
+    if not args.interactive and (not args.service or not args.method):
+        parser.error(
+            f"Either {colorize('--interactive', 'white')}/{colorize('-i', 'white')} mode or {colorize('service/method', 'white')} must be specified"
+        )
+
     # Handle discovery mode
     if args.discover:
         if args.host:
@@ -175,12 +191,6 @@ def main():
             print("\nPassword entry cancelled.")
             sys.exit(1)
 
-    # Validate arguments
-    if not args.interactive and (not args.service or not args.method):
-        parser.error(
-            f"Either {colorize('--interactive', 'white')}/{colorize('-i', 'white')} mode or {colorize('service/method', 'white')} must be specified"
-        )
-
     try:
         # Create ONVIF client
         client = ONVIFClient(
