@@ -1,7 +1,9 @@
 # onvif/operator.py
 
 import os
+import warnings
 import requests
+import urllib3
 
 from enum import Enum
 from zeep import Settings, Transport, Client, CachingClient
@@ -72,6 +74,10 @@ class ONVIFOperator:
         session = requests.Session()
         session.verify = verify_ssl
 
+        # Format SSL warnings to be more concise when verify_ssl is False
+        if not verify_ssl:
+            warnings.simplefilter("once", urllib3.exceptions.InsecureRequestWarning)
+
         transport_kwargs = {"session": session, "timeout": timeout}
 
         if cache in (CacheMode.DB, CacheMode.ALL):
